# pdb4all
*Convert between common protein pdb formats and names*

### Usage
```
  pdb4all <options> .pdb
```

### Currently supported ForceFields name conventions
  * Amber
  * Charmm
  * OPLS

### Currently supported formats (software)
  * Fasta
  * Maestro
  * GROMACS
  * fDynamo
